@@ -1,11 +1,10 @@
-use 5.008;    # utf8
+use 5.006;
 use strict;
 use warnings;
-use utf8;
 
 package Dist::Zilla::Util::Test::KENTNL::dztest;
 
-our $VERSION = '1.005010';
+our $VERSION = '1.005011';
 
 # ABSTRACT: Shared dist testing logic for easy dzil things
 
@@ -562,7 +561,7 @@ Dist::Zilla::Util::Test::KENTNL::dztest - Shared dist testing logic for easy dzi
 
 =head1 VERSION
 
-version 1.005010
+version 1.005011
 
 =head1 SYNOPSIS
 
